import { Button, Form, Input, Modal, Radio } from 'antd';
import 'antd/dist/antd.css';
import React from 'react';
import { ChangeUserInfoRequest, ERole, UserInfo } from '../../api';
import { userController } from '../../controllers';
import { ShowToast } from '../../utils/alerts';

interface ModalProps {
    onCancel: () => void;
    userInfo: UserInfo;
}

/**
 * Creates a modal window that loads documents to the app.
 * @returns The modal window.
 */
const EditUserModal: React.FC<ModalProps> = ({ onCancel, userInfo }: ModalProps) => {
    /**
     * Handles successful closing of the modal window.
     */
    const handleOk = () => {
        onCancel();
    };

    /**
     * Handles cancelling of the model window.
     */
    const handleCancel = () => {
        onCancel();
    };

    const onFinish = async (values: any) => {
        const req: ChangeUserInfoRequest = {
            password: values.password,
        };
        if (userInfo.id) {
            userController.userUserIdPut(userInfo.id, req).then((r) => {
                ShowToast('Heslo úspěšně změněno', 'success', 3000, 'top-end');
                onCancel();
            });
        }
    };

    const onFinishFailed = (errorInfo: any) => {
        ShowToast('Zadané údaje nejsou validní', 'error', 3000, 'top-end');
    };

    return (
        <Modal
            title={'Změnit heslo uživatele ' + userInfo.username}
            onOk={handleOk}
            visible={true}
            onCancel={handleCancel}
            footer={null}
            width={400}
            centered
        >
            <Form
                onFinish={onFinish}
                onFinishFailed={onFinishFailed}
                autoComplete="off"
                labelCol={{ span: 4 }}
                layout="horizontal"
            >
                <Form.Item
                    name="password"
                    rules={[{ required: true, message: 'Prosím zadejte heslo' }]}
                >
                    <Input.Password placeholder="Heslo" />
                </Form.Item>
                <Form.Item>
                    <Button type="primary" htmlType="submit" className="w-100">
                        Změnit
                    </Button>
                </Form.Item>
            </Form>
        </Modal>
    );
};

export default EditUserModal;
